==> apache-iceberg-1.7.0.tar.gz: apache-iceberg-1.7.0/flink/v1.20/flink/src/main/java/org/apache/iceberg/flink/maintenance/operator/TableMaintenanceMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.flink.maintenance.operator;

public class TableMaintenanceMetrics {
  public static final String GROUP_KEY = "maintenanceTask";
  public static final String GROUP_VALUE_DEFAULT = "maintenanceTask";

  // TriggerManager metrics
  public static final String RATE_LIMITER_TRIGGERED = "rateLimiterTriggered";
  public static final String CONCURRENT_RUN_THROTTLED = "concurrentRunThrottled";
  public static final String TRIGGERED = "triggered";
  public static final String NOTHING_TO_TRIGGER = "nothingToTrigger";

  // LockRemover metrics
  public static final String SUCCEEDED_TASK_COUNTER = "succeededTasks";
  public static final String FAILED_TASK_COUNTER = "failedTasks";
  public static final String LAST_RUN_DURATION_MS = "lastRunDurationMs";

  private TableMaintenanceMetrics() {
    // do not instantiate
  }
}

==> apache-iceberg-1.9.2.tar.gz: apache-iceberg-1.9.2/flink/v1.19/flink/src/main/java/org/apache/iceberg/flink/maintenance/operator/TableMaintenanceMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.flink.maintenance.operator;

public class TableMaintenanceMetrics {
  public static final String GROUP_KEY = "maintenance";
  public static final String TASK_NAME_KEY = "taskName";
  public static final String TASK_INDEX_KEY = "taskIndex";
  public static final String TABLE_NAME_KEY = "tableName";

  // TriggerManager metrics
  public static final String RATE_LIMITER_TRIGGERED = "rateLimiterTriggered";
  public static final String CONCURRENT_RUN_THROTTLED = "concurrentRunThrottled";
  public static final String TRIGGERED = "triggered";
  public static final String NOTHING_TO_TRIGGER = "nothingToTrigger";

  // LockRemover metrics
  public static final String SUCCEEDED_TASK_COUNTER = "succeededTasks";
  public static final String FAILED_TASK_COUNTER = "failedTasks";
  public static final String LAST_RUN_DURATION_MS = "lastRunDurationMs";

  // DeleteFiles metrics
  public static final String DELETE_FILE_FAILED_COUNTER = "deleteFailed";
  public static final String DELETE_FILE_SUCCEEDED_COUNTER = "deleteSucceeded";

  private TableMaintenanceMetrics() {
    // do not instantiate
  }
}
